"use client"

import type React from "react"
import { useState, useEffect } from "react"
import { useRouter } from "next/navigation"
import { useAuth } from "@/contexts/auth-context"
import { updateProfile, updatePassword, EmailAuthProvider, reauthenticateWithCredential } from "firebase/auth"
import { auth } from "@/lib/firebase/config"
import { Card, CardContent, CardDescription, CardFooter, CardHeader, CardTitle } from "@/components/ui/card"
import { Avatar, AvatarFallback, AvatarImage } from "@/components/ui/avatar"
import { Button } from "@/components/ui/button"
import { Input } from "@/components/ui/input"
import { Label } from "@/components/ui/label"
import { Loader2, UserIcon, Lock, AlertCircle, Camera, Shield, ChevronLeft, Eye, EyeOff } from "lucide-react"
import { useToast } from "@/hooks/use-toast"
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs"
import { useLanguage } from "@/contexts/language-context"
import { Alert, AlertDescription } from "@/components/ui/alert"
import { motion } from "framer-motion"
import Link from "next/link"
import { Separator } from "@/components/ui/separator"

export default function ProfilePage() {
  const { user, loading } = useAuth()
  const router = useRouter()
  const { toast } = useToast()
  const { t } = useLanguage()

  const [displayName, setDisplayName] = useState("")
  const [isUpdating, setIsUpdating] = useState(false)
  const [updateError, setUpdateError] = useState<string | null>(null)

  // Password change states
  const [currentPassword, setCurrentPassword] = useState("")
  const [newPassword, setNewPassword] = useState("")
  const [confirmPassword, setConfirmPassword] = useState("")
  const [isChangingPassword, setIsChangingPassword] = useState(false)
  const [passwordError, setPasswordError] = useState<string | null>(null)
  const [showCurrentPassword, setShowCurrentPassword] = useState(false)
  const [showNewPassword, setShowNewPassword] = useState(false)
  const [showConfirmPassword, setShowConfirmPassword] = useState(false)

  useEffect(() => {
    // Redirect if not logged in and loading is finished
    if (!loading && !user) {
      router.push("/auth")
    } else if (user) {
      // Initialize display name from user profile
      setDisplayName(user.displayName || "")
    }
  }, [user, loading, router])

  const handleUpdateProfile = async (e: React.FormEvent) => {
    e.preventDefault()
    if (!user || !auth.currentUser) {
      setUpdateError(t("mustBeLoggedIn"))
      return
    }

    // Prevent updating if display name hasn't changed
    if (displayName.trim() === (user.displayName || "")) {
      toast({
        title: t("noChanges"),
        description: t("displayNameUpToDate"),
      })
      return
    }

    setIsUpdating(true)
    setUpdateError(null)

    try {
      await updateProfile(auth.currentUser, {
        displayName: displayName.trim(),
      })
      toast({
        title: t("profileUpdated"),
        description: t("displayNameUpdated"),
        className: "bg-emerald-50 border-emerald-200 dark:bg-emerald-900/20 dark:border-emerald-900/30",
      })
    } catch (error: any) {
      console.error("Error updating profile:", error)
      const message = error.message || t("profileUpdateError")
      setUpdateError(message)
      toast({
        variant: "destructive",
        title: t("updateError"),
        description: message,
      })
    } finally {
      setIsUpdating(false)
    }
  }

  const handleChangePassword = async (e: React.FormEvent) => {
    e.preventDefault()

    if (!user || !auth.currentUser || !user.email) {
      setPasswordError(t("emailAccountRequired"))
      return
    }

    // Validate password inputs
    if (!currentPassword) {
      setPasswordError(t("currentPasswordRequired"))
      return
    }

    if (!newPassword) {
      setPasswordError(t("newPasswordRequired"))
      return
    }

    if (newPassword.length < 6) {
      setPasswordError(t("passwordTooShort"))
      return
    }

    if (newPassword !== confirmPassword) {
      setPasswordError(t("passwordsDoNotMatch"))
      return
    }

    setIsChangingPassword(true)
    setPasswordError(null)

    try {
      // First, re-authenticate the user
      const credential = EmailAuthProvider.credential(user.email, currentPassword)

      await reauthenticateWithCredential(auth.currentUser, credential)

      // Then change the password
      await updatePassword(auth.currentUser, newPassword)

      // Clear form and show success message
      setCurrentPassword("")
      setNewPassword("")
      setConfirmPassword("")

      toast({
        title: t("passwordUpdated"),
        description: t("passwordChanged"),
        className: "bg-emerald-50 border-emerald-200 dark:bg-emerald-900/20 dark:border-emerald-900/30",
      })
    } catch (error: any) {
      console.error("Error changing password:", error)

      let message = t("passwordChangeError")

      if (error.code === "auth/wrong-password") {
        message = t("incorrectCurrentPassword")
      } else if (error.code === "auth/weak-password") {
        message = t("weakPassword")
      } else if (error.code === "auth/requires-recent-login") {
        message = t("requiresRecentLogin")
      }

      setPasswordError(message)
      toast({
        variant: "destructive",
        title: t("passwordChangeError"),
        description: message,
      })
    } finally {
      setIsChangingPassword(false)
    }
  }

  // Helper to get initials from display name
  const getInitials = (name: string | null | undefined): string => {
    if (!name) return ""
    const names = name.split(" ")
    if (names.length === 1) return names[0].charAt(0).toUpperCase()
    return (names[0].charAt(0) + names[names.length - 1].charAt(0)).toUpperCase()
  }

  // Check if the account is a provider account (like Google) that doesn't support password change
  const isProviderAccount = user?.providerData?.[0]?.providerId !== "password"

  if (loading || !user) {
    return (
      <div className="flex justify-center items-center min-h-[calc(100vh-4rem)]">
        <Loader2 className="h-12 w-12 animate-spin text-emerald-500" />
      </div>
    )
  }

  return (
    <div className="min-h-[calc(100vh-4rem)] bg-gradient-to-b from-slate-50 to-slate-100 dark:from-slate-900 dark:to-slate-800 py-8 px-4">
      <div className="container mx-auto max-w-2xl">
        <div className="mb-6 flex items-center">
          <Button
            variant="ghost"
            size="sm"
            className="mr-2 text-slate-600 hover:text-slate-900 dark:text-slate-400 dark:hover:text-slate-200"
            onClick={() => router.push("/")}
          >
            <ChevronLeft className="mr-1 h-4 w-4" />
            {t("back")}
          </Button>
          <h1 className="text-2xl font-bold text-slate-800 dark:text-slate-200">{t("profileSettings")}</h1>
        </div>

        <motion.div initial={{ opacity: 0, y: 20 }} animate={{ opacity: 1, y: 0 }} transition={{ duration: 0.5 }}>
          <Card className="overflow-hidden border-0 shadow-lg bg-white dark:bg-slate-900">
            <CardHeader className="relative p-0">
              <div className="bg-gradient-to-r from-emerald-600 to-teal-600 h-32 w-full" />
              <div className="absolute -bottom-12 left-0 w-full flex justify-center">
                <div className="relative">
                  <Avatar className="h-24 w-24 border-4 border-white dark:border-slate-900 shadow-md">
                    <AvatarImage src={user.photoURL ?? undefined} alt={user.displayName ?? "User"} />
                    <AvatarFallback className="text-3xl bg-emerald-100 text-emerald-700 dark:bg-emerald-900 dark:text-emerald-300">
                      {getInitials(user.displayName)}
                    </AvatarFallback>
                  </Avatar>
                  <Button
                    size="icon"
                    variant="secondary"
                    className="absolute bottom-0 right-0 h-8 w-8 rounded-full shadow-md bg-emerald-500 hover:bg-emerald-600 text-white"
                    disabled
                  >
                    <Camera className="h-4 w-4" />
                    <span className="sr-only">{t("changePhoto")}</span>
                  </Button>
                </div>
              </div>
            </CardHeader>
            <CardContent className="pt-16 px-6 pb-6">
              <div className="text-center mb-6">
                <CardTitle className="text-2xl font-bold text-slate-800 dark:text-white">
                  {user.displayName || t("user")}
                </CardTitle>
                <CardDescription className="text-slate-500 dark:text-slate-400">{user.email}</CardDescription>
              </div>

              <Tabs defaultValue="profile" className="w-full">
                <TabsList className="grid w-full grid-cols-2 mb-6 bg-slate-100 dark:bg-slate-800">
                  <TabsTrigger
                    value="profile"
                    className="data-[state=active]:bg-emerald-500 data-[state=active]:text-white"
                  >
                    <UserIcon className="mr-2 h-4 w-4" />
                    {t("profileTab")}
                  </TabsTrigger>
                  <TabsTrigger
                    value="security"
                    className="data-[state=active]:bg-emerald-500 data-[state=active]:text-white"
                  >
                    <Shield className="mr-2 h-4 w-4" />
                    {t("securityTab")}
                  </TabsTrigger>
                </TabsList>

                {/* Profile Tab */}
                <TabsContent value="profile">
                  <form onSubmit={handleUpdateProfile} className="space-y-6">
                    <div className="space-y-2">
                      <Label htmlFor="email" className="text-slate-700 dark:text-slate-300">
                        {t("email")}
                      </Label>
                      <Input
                        id="email"
                        type="email"
                        value={user.email || t("noEmailProvided")}
                        disabled
                        className="bg-slate-50 border-slate-200 text-slate-500 cursor-not-allowed dark:bg-slate-800/50 dark:border-slate-700 dark:text-slate-400"
                      />
                      <p className="text-xs text-slate-500 dark:text-slate-400">{t("emailCannotBeChanged")}</p>
                    </div>
                    <div className="space-y-2">
                      <Label htmlFor="displayName" className="text-slate-700 dark:text-slate-300">
                        {t("displayName")}
                      </Label>
                      <Input
                        id="displayName"
                        type="text"
                        placeholder={t("yourName")}
                        value={displayName}
                        onChange={(e) => setDisplayName(e.target.value)}
                        disabled={isUpdating}
                        className="border-slate-200 focus-visible:ring-emerald-500 dark:border-slate-700"
                      />
                    </div>
                    {updateError && (
                      <Alert
                        variant="destructive"
                        className="bg-red-50 border-red-200 dark:bg-red-900/20 dark:border-red-900/30"
                      >
                        <AlertCircle className="h-4 w-4" />
                        <AlertDescription>{updateError}</AlertDescription>
                      </Alert>
                    )}
                    <Button
                      type="submit"
                      className="w-full bg-emerald-600 hover:bg-emerald-700 text-white"
                      disabled={isUpdating}
                    >
                      {isUpdating ? (
                        <Loader2 className="mr-2 h-4 w-4 animate-spin" />
                      ) : (
                        <UserIcon className="mr-2 h-4 w-4" />
                      )}
                      {t("updateProfile")}
                    </Button>
                  </form>
                </TabsContent>

                {/* Security Tab */}
                <TabsContent value="security">
                  {isProviderAccount ? (
                    <Alert className="bg-slate-50 border-slate-200 dark:bg-slate-800 dark:border-slate-700">
                      <AlertCircle className="h-5 w-5 text-slate-500 dark:text-slate-400" />
                      <AlertDescription className="text-slate-700 dark:text-slate-300">
                        <p className="font-medium mb-1">{t("passwordUnavailable")}</p>
                        <p className="text-sm text-slate-500 dark:text-slate-400">
                          {t("providerAccount").replace(
                            "{provider}",
                            user.providerData[0].providerId === "google.com" ? "Google" : t("externalProvider"),
                          )}
                        </p>
                      </AlertDescription>
                    </Alert>
                  ) : (
                    <form onSubmit={handleChangePassword} className="space-y-6">
                      <div className="space-y-2">
                        <Label htmlFor="currentPassword" className="text-slate-700 dark:text-slate-300">
                          {t("currentPassword")}
                        </Label>
                        <div className="relative">
                          <Input
                            id="currentPassword"
                            type={showCurrentPassword ? "text" : "password"}
                            placeholder={t("enterCurrentPassword")}
                            value={currentPassword}
                            onChange={(e) => setCurrentPassword(e.target.value)}
                            disabled={isChangingPassword}
                            className="pr-10 border-slate-200 focus-visible:ring-emerald-500 dark:border-slate-700"
                          />
                          <button
                            type="button"
                            onClick={() => setShowCurrentPassword(!showCurrentPassword)}
                            className="absolute right-3 top-1/2 -translate-y-1/2 text-slate-400 hover:text-slate-600 dark:hover:text-slate-300"
                            tabIndex={-1}
                          >
                            {showCurrentPassword ? <EyeOff className="h-4 w-4" /> : <Eye className="h-4 w-4" />}
                          </button>
                        </div>
                      </div>
                      <Separator className="my-4 bg-slate-200 dark:bg-slate-700" />
                      <div className="space-y-2">
                        <Label htmlFor="newPassword" className="text-slate-700 dark:text-slate-300">
                          {t("newPassword")}
                        </Label>
                        <div className="relative">
                          <Input
                            id="newPassword"
                            type={showNewPassword ? "text" : "password"}
                            placeholder={t("enterNewPassword")}
                            value={newPassword}
                            onChange={(e) => setNewPassword(e.target.value)}
                            disabled={isChangingPassword}
                            className="pr-10 border-slate-200 focus-visible:ring-emerald-500 dark:border-slate-700"
                          />
                          <button
                            type="button"
                            onClick={() => setShowNewPassword(!showNewPassword)}
                            className="absolute right-3 top-1/2 -translate-y-1/2 text-slate-400 hover:text-slate-600 dark:hover:text-slate-300"
                            tabIndex={-1}
                          >
                            {showNewPassword ? <EyeOff className="h-4 w-4" /> : <Eye className="h-4 w-4" />}
                          </button>
                        </div>
                        <p className="text-xs text-slate-500 dark:text-slate-400">{t("passwordRequirement")}</p>
                      </div>
                      <div className="space-y-2">
                        <Label htmlFor="confirmPassword" className="text-slate-700 dark:text-slate-300">
                          {t("confirmNewPassword")}
                        </Label>
                        <div className="relative">
                          <Input
                            id="confirmPassword"
                            type={showConfirmPassword ? "text" : "password"}
                            placeholder={t("confirmNewPassword")}
                            value={confirmPassword}
                            onChange={(e) => setConfirmPassword(e.target.value)}
                            disabled={isChangingPassword}
                            className="pr-10 border-slate-200 focus-visible:ring-emerald-500 dark:border-slate-700"
                          />
                          <button
                            type="button"
                            onClick={() => setShowConfirmPassword(!showConfirmPassword)}
                            className="absolute right-3 top-1/2 -translate-y-1/2 text-slate-400 hover:text-slate-600 dark:hover:text-slate-300"
                            tabIndex={-1}
                          >
                            {showConfirmPassword ? <EyeOff className="h-4 w-4" /> : <Eye className="h-4 w-4" />}
                          </button>
                        </div>
                      </div>
                      {passwordError && (
                        <Alert
                          variant="destructive"
                          className="bg-red-50 border-red-200 dark:bg-red-900/20 dark:border-red-900/30"
                        >
                          <AlertCircle className="h-4 w-4" />
                          <AlertDescription>{passwordError}</AlertDescription>
                        </Alert>
                      )}
                      <Button
                        type="submit"
                        className="w-full bg-emerald-600 hover:bg-emerald-700 text-white"
                        disabled={isChangingPassword}
                      >
                        {isChangingPassword ? (
                          <Loader2 className="mr-2 h-4 w-4 animate-spin" />
                        ) : (
                          <Lock className="mr-2 h-4 w-4" />
                        )}
                        {t("changePassword")}
                      </Button>
                    </form>
                  )}
                </TabsContent>
              </Tabs>
            </CardContent>
            <CardFooter className="px-6 py-4 border-t border-slate-200 dark:border-slate-700 flex flex-col gap-2">
              <p className="text-xs text-slate-500 dark:text-slate-400 text-center w-full">{t("accountSecurity")}</p>
              <div className="flex justify-center gap-2 text-xs">
                <Link
                  href="/terms"
                  className="text-emerald-600 hover:text-emerald-700 dark:text-emerald-500 dark:hover:text-emerald-400"
                >
                  {t("terms")}
                </Link>
                <span className="text-slate-400">•</span>
                <Link
                  href="/privacy"
                  className="text-emerald-600 hover:text-emerald-700 dark:text-emerald-500 dark:hover:text-emerald-400"
                >
                  {t("privacy")}
                </Link>
                <span className="text-slate-400">•</span>
                <Link
                  href="/help"
                  className="text-emerald-600 hover:text-emerald-700 dark:text-emerald-500 dark:hover:text-emerald-400"
                >
                  {t("help")}
                </Link>
              </div>
            </CardFooter>
          </Card>
        </motion.div>
      </div>
    </div>
  )
}
